Welcome to the Documentation for the Batteries package!
================================================================

.. toctree::
    :maxdepth: 2
    :caption: Contents:

    pages/usage/introduction
    pages/references/preprocessing
    pages/references/models
    pages/references/misc


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
